==> haskell-base-prelude-1.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.3
id: base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
key: base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
abi: 9396e903f9c3781aaf5fd627a604df05
exposed: True
exposed-modules:
    BasePrelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-prelude-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-prelude-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/base-prelude-1.3
hs-libraries: HSbase-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.3
id: base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
key: base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
abi: 245e80fdd299e8226b4c88906d488d38
exposed: True
exposed-modules:
    BasePrelude
import-dirs: /usr/lib/ghc-8.6.1/site-local/base-prelude-1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/base-prelude-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/base-prelude-1.3
hs-libraries: HSbase-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
